Ext.namespace("dSA", "dSA.dialogs");

dSA.dialogs.DefaultDialogContentPanel = Ext.extend(Ext.Panel,
{
    constructor: function(config)
    {
        var items = [];

        if (config.strings !== undefined)
        {
            var i;
            for (i = 0; i < config.strings.length; i++)
            {
                var item =
                {
                    xtype: 'label',
                    html: config.strings[i],
                    cls: 'x-text-align-left x-text-nowrap'
                };
                items.push(item);
             }
        }
        Ext.apply(this,
        {
            xtype: 'panel',
            padding: 5,
            layout: 'table',
            layoutConfig:
            {
                columns: 2
            },
            items: items
        });

        dSA.dialogs.DefaultDialogContentPanel.superclass.constructor.apply(this,
            arguments);
    }
});

Ext.reg('dsadialogcontentpanel', dSA.dialogs.DefaultDialogContentPanel);

dSA.dialogs.CreateKeyValPanel = function(obj, width)
{
    var items = [];
    var i;
    for (i = 0; i < obj.length; i++)
    {
        items.push(new Ext.form.Label(
        {
            xtype: 'label',
            ctCls: 'x-text-nowrap',
            html: String(obj[i].key) + ": " + '&nbsp;'
        }));

        items.push(new Ext.form.Label(
        {
            xtype: 'label',
            ctCls: 'x-text-align-left x-text-nowrap',
            html: String(obj[i].value)
        }));
    }

    var kvp =
    {
        xtype: 'panel',
        padding: 5,
        bodyCfg:
        {
            cls: 'x-window-body x-window-mc'
        },
        bodyBorder: false,
        border: false,
        frame: false,
        layout: 'table',
        layoutConfig:
        {
            columns: 2
        },
        items: items
    };

    if (width !== undefined)
    {
        kvp.width = width;
    }

    return kvp;
};

dSA.dialogs.CreateDefaultDeviceInfoPanel = function(name, dsuid, device)
{
    dsuid = dSA.util.shortDSUID(dsuid);
    name = dSA.util.getName(name);

    var msgname = dSA._("Device name");
    var msgid = dSA._("Device ID");
    if (device !== true)
    {
        msgname = dSA._("dSM name");
        msgid = dSA._("dSM ID");
    }

    return dSA.dialogs.CreateKeyValPanel(
    [
        { key: msgname, value: name },
        { key: msgid, value: dsuid }
    ]);
};

dSA.dialogs.DefaultDialogWindow = Ext.extend(Ext.Window, {
    constructor: function(config)
    {
        var cancelButtonText = dSA._("Close");

        if (config.cancelButtonText !== undefined)
        {
            cancelButtonText = config.cancelButtonText;
        }

        if (config.width === undefined)
        {
            config.width = 400;
        }

        if (config.device === undefined)
        {
            config.device = true;
        }

        var items = [];

        if (config.noinfo !== true)
        {
            items = [ dSA.dialogs.CreateDefaultDeviceInfoPanel(config.name,
                                                               config.dsuid,
                                                               config.device) ];
        }

        if ((config.extraItems !== undefined) && (config.extraItems.length > 0))
        {
            items = items.concat(config.extraItems);
        }

        if (config.maskElement === undefined)
        {
            this.maskElement = this.findParentByType(Ext.Viewport).el;
        }

        this.cancelButton =
        {
            xtype: 'button',
            text: cancelButtonText,
            scope: this,
            handler: function()
            {
                if (this.maskElement !== null)
                {
                    this.maskElement.unmask();
                }
                this.close();
            }
        };

        var buttons = [  ];

        if ((config.buttons !== undefined) && (config.buttons.length > 0))
        {
            buttons = config.buttons;
        }

        buttons.push(this.cancelButton);

        Ext.apply(this,
        {
            layout: 'table',
            layoutConfig:
            {
                columns: 1,
                tableAttrs:
                {
                    width: '100%'
                }
            },
            padding: 10,
            width: config.width,
            resizable: false,
            title: config.title,
            items: items,
            buttons: buttons
        });

        dSA.dialogs.DefaultDialogWindow.superclass.constructor.apply(this,
            arguments);

        if (this.maskElement !== null)
        {
            this.maskElement.mask();
        }

        this.on('beforedestroy',
            function(component)
            {
                if (this.maskElement !== null)
                {
                    this.maskElement.unmask();
                }
            },
            this);
    }
});

Ext.reg('dsadefaultwindow', dSA.dialogs.DefaultDialogWindow);

